# Sugerencias para mejorar las traducciones de la documentación

Gracias por tu interés en este proyecto. La documentación en idiomas distintos al inglés se traduce automáticamente mediante modelos de lenguaje avanzados, por lo que los errores son inevitables. Si detectas problemas en un idioma que conoces, te damos la más cordial bienvenida a enviar sugerencias de mejora.

Antes de comenzar a contribuir, por favor tómate un momento para leer la siguiente guía, que te ayudará a asegurar que tus sugerencias puedan ser aceptadas sin problemas.

# Enviar sugerencias a través de Weblate

Utilizamos [Weblate](https://weblate.org/) para gestionar las traducciones de nuestra documentación. Puedes consultar el estado actual de las traducciones y enviar sugerencias en la [página de Weblate del proyecto](https://hosted.weblate.org/projects/pdfmathtranslate-next/).

## Cómo enviar una sugerencia

Es muy sencillo proponer mejoras en las traducciones a través de Weblate, y ni siquiera necesitas registrar una cuenta. Sigue leyendo para conocer el proceso paso a paso.

Supongamos que deseas mejorar la primera frase en la sección "命令行参数" de [高级选项 → 高级](docs/en/advanced/advanced.md):

1. Abre la [página de Weblate del proyecto](https://hosted.weblate.org/projects/pdfmathtranslate-next/).

2. Haz clic en `Search` en la parte superior.

<img src="./../../images/weblate/homepage.png" width="420px" alt="homepage"/>

3. En "Filtro", ingresa el segmento de texto que deseas encontrar. Texto parcial está bien.

<img src="./../../images/weblate/search.png" alt="search"/>

Cuando hayas terminado, presiona <kbd>Enter</kbd>.

4. Después de presionar <kbd>Enter</kbd>, serás llevado a la página de resultados de búsqueda. Haz clic en el resultado que prefieras para abrir la vista de edición.

<img src="./../../images/weblate/search-result.png" alt="search result"/>

5. En la vista de edición, realiza los cambios en la traducción. Cuando termines, haz clic en <kbd>Sugerir</kbd>. Eso es todo—has completado con éxito una contribución.

<img src="./../../images/weblate/suggestion.png" alt="suggestion"/>

Revisaremos tu sugerencia después de que sea enviada. Una vez aprobada, tus cambios aparecerán en la documentación.

<div align="right"> 
<h6><small>Parte del contenido de esta página ha sido traducido por GPT y puede contener errores.</small></h6>